@@ -16,6 +16,7 @@ import os
 import re
 import six
 from six.moves.urllib import parse
+import string
 import subprocess
 
 
@@ -42,9 +43,35 @@ def _guess_cgit_link():
 def _html_page_context(app, pagename, templatename, context, doctree):
     # Insert the cgit link into the template context.
     context['cgit_link'] = app.config.oslosphinx_cgit_link
+    context['other_versions'] = _get_other_versions(app)
     return None
 
 
+def _get_other_versions(app):
+    if not app.config.html_theme_options.get('show_other_versions', False):
+        return []
+
+    git_cmd = ["git", "tag"]
+    try:
+        raw_version_list = subprocess.Popen(
+            git_cmd, stdout=subprocess.PIPE).communicate()[0]
+    except OSError:
+        app.warn('Cannot get tags from git repository. '
+                 'Not setting "other_versions".')
+        raw_version_list = ''
+
+    # grab last five that start with a number and reverse the order
+    if six.PY3:
+        raw_version_list = raw_version_list.decode("utf8")
+    _tags = [t.strip("'") for t in raw_version_list.split('\n')]
+    other_versions = [
+        t for t in _tags if t and t[0] in string.digits
+        # Don't show alpha, beta or release candidate tags
+        and 'rc' not in t and 'a' not in t and 'b' not in t
+    ][:-5:-1]
+    return other_versions
+
+
 def builder_inited(app):
     theme_dir = os.path.join(os.path.dirname(__file__), 'theme')
     app.info('Using openstack theme from %s' % theme_dir)
